@@ -1,7 +1,7 @@
 import argparse
 from .cli import Niscli
 
-__version__ = "0.0.2"
+__version__ = "0.1"
 
 # parse arguments
 argparser = argparse.ArgumentParser(prog="nisanyan_cli")
@@ -11,9 +11,6 @@ argparser.add_argument(
     nargs="*",
     help="<word>",
 )
-argparser.add_argument(
-    "-p", "--plain", action="store_true", help="returns plain output"
-)
 argparser.add_argument(
     "-v", "--version", action="version", version="%(prog)s v" + __version__
 )
@@ -22,13 +19,7 @@ args = argparser.parse_args()
 
 def cli():
     word = " ".join(args.word)
-    if len(args.word) > 0:
-        if args.plain:
-            Niscli(word).plain_output()
-        else:
-            Niscli(word).rich_output()
-    else:
-        print("kelime giriniz.")
+    Niscli(word)
 
 
 if __name__ == "__main__":
